@@ -66,6 +66,7 @@
 #include <csetjmp>
 #include <csignal>
 #include <fcntl.h>
+#include <unistd.h>
 
 
 #define MESSEVENTDELAY	20		// how often VPBs are polled by driver
@@ -2100,14 +2101,14 @@ void ring_station_async(int board, int port, int cadence)
 	if(cadence == VPB_RING_STATION_OFF) {
 		uint16_t mess[PC_LRING_OFF] = { PC_LRING_OFF,
 						PC_RING_OFF,
-						port,
-						cadence };
+						uint16_t(port),
+						uint16_t(cadence) };
 		vpb_c->PutMessageVPB(board,mess);
 	} else {
 		uint16_t mess[PC_LRING_ON]  = { PC_LRING_ON,
 						PC_RING_ON,
-						port,
-						cadence };
+						uint16_t(port),
+						uint16_t(cadence) };
 		vpb_c->PutMessageVPB(board,mess);
 	}
 } //}}}
