@@ -38,6 +38,7 @@
 #include <cstdlib>
 #include <cstring>
 #include <fcntl.h>
+#include <unistd.h>
 #include <sys/ioctl.h>
 
 
@@ -212,7 +213,7 @@ VPBRegister::VPBRegister()
 				if( ! GetProcfsInfo(node, buf, sizeof(buf)) )
 					break;
 
-				VTCORE_CARD  card = { i, 0, NULL };
+				VTCORE_CARD  card = { int(i), 0, NULL };
 
 				if( strncmp("OpenPCI", buf, 7) == 0 )
 					card.type = VPB_OPCI;
