@@ -264,12 +264,12 @@ void deltonedet(int chdev, const VPB_DETECT &d)
 	// determine if a detector with this identifier already exists
 
 	int exists = 0;
-	int index = 0;
+//	int index = 0;
 
 	for(i=0; i < numtd[chdev]; ++i) {
 		if (td[chdev*VPB_MD+i].tone_id == id) {
 			exists = 1;
-			index = i;
+//			index = i;
 			break;
 		}
 	}
