@@ -51,6 +51,7 @@ extern "C" {
 #include <cstdio>
 #include <cstdlib>
 #include <cstring>
+#include <unistd.h>
 
 
 /* VPB Driver stuff */
@@ -123,24 +124,24 @@ public:
 typedef HostToneGen ProslicToneGen; //XXX
 #endif
 
-static void vtcore_set_ringing(int board, int ch, int rings)
+static void vtcore_set_ringing(uint8_t board, uint8_t ch, int rings)
 { //{{{
 	VT_DATA  mess = { board:   board,
 			  channel: ch,
-			  length:  rings,
+			  length:  unsigned(rings),
 			  data:    NULL
 			};
 
 	if (rings < 0 || rings > 255)
-		mprintf("[%d/%d] Set ringing failed! Requires 0 <= rings"
+		mprintf("[%u/%u] Set ringing failed! Requires 0 <= rings"
 			" <= 255, but rings is %d\n", board, ch, rings);
 	else if( ioctl(pci_fd, VT_IOC_FXS_RING, &mess) < 0 )
-		mprintf("[%d/%d] Set ringing failed!\n",board, ch);
+		mprintf("[%u/%u] Set ringing failed!\n",board, ch);
 	else
-		mprintf("[%d/%d] Set ringing to %d\n",board, ch, rings);
+		mprintf("[%u/%u] Set ringing to %d\n",board, ch, rings);
 } //}}}
 
-static int vtcore_sethook(int board, int port, int state)
+static int vtcore_sethook(uint8_t board, uint8_t port, unsigned state)
 { //{{{
 	VT_DATA  mess = { board:   board,
 			  channel: port,
@@ -150,7 +151,7 @@ static int vtcore_sethook(int board, int port, int state)
 	return ioctl(pci_fd, VT_IOC_HOOK, &mess);
 } //}}}
 
-static int vtcore_echocan_on(int fd, int board, int port)
+static int vtcore_echocan_on(int fd, uint8_t board, uint8_t port)
 { //{{{
 	VT_DATA  mess = { board:   board,
 			  channel: port,
@@ -160,7 +161,7 @@ static int vtcore_echocan_on(int fd, int board, int port)
 	return ioctl(fd, VT_IOC_ECHOCAN_ON, &mess) < 0 ? -1 : 0;
 } //}}}
 
-static int vtcore_echocan_off(int fd, int board, int port)
+static int vtcore_echocan_off(int fd, uint8_t board, uint8_t port)
 { //{{{
 	VT_DATA  mess = { board:   board,
 			  channel: port,
@@ -170,24 +171,24 @@ static int vtcore_echocan_off(int fd, int board, int port)
 	return ioctl(fd, VT_IOC_ECHOCAN_OFF, &mess) < 0 ? -1 : 0;
 } //}}}
 
-static int vtcore_listenon(int fd, int board, uint16_t *m)
+static int vtcore_listenon(int fd, uint8_t board, uint16_t *m)
 { //{{{
-	VT_DATA  msg2 = { board:   m[3],
-			  channel: m[4],
+	VT_DATA  msg2 = { board:   uint8_t(m[3]),
+			  channel: uint8_t(m[4]),
 			  length:  0,
 			  data:    NULL
 			};
 	VT_DATA  mess = { board:   board,
-			  channel: m[2],
+			  channel: uint8_t(m[2]),
 			  length:  sizeof(VT_DATA),
 			  data:    &msg2
 			};
 	return ioctl(fd, VT_IOC_LISTEN, &mess) < 0 ? -1 : 0;
 } //}}}
 
-static void vtcore_set_rec_gain(VPBREG &v, int port, int gain)
+static void vtcore_set_rec_gain(VPBREG &v, uint8_t port, unsigned gain)
 { //{{{
-	VT_DATA  mess = { board:   v.cardtypnum,
+	VT_DATA  mess = { board:   uint8_t(v.cardtypnum),
 			  channel: port,
 			  length:  gain,
 			  data:    NULL
@@ -195,9 +196,9 @@ static void vtcore_set_rec_gain(VPBREG &v, int port, int gain)
 	ioctl(pci_fd, VT_IOC_SET_RECGAIN, &mess);
 } //}}}
 
-static void vtcore_set_play_gain(VPBREG &v, int port, int gain)
+static void vtcore_set_play_gain(VPBREG &v, uint8_t port, unsigned gain)
 { //{{{
-	VT_DATA  mess = { board:   v.cardtypnum,
+	VT_DATA  mess = { board:   uint8_t(v.cardtypnum),
 			  channel: port,
 			  length:  gain,
 			  data:    NULL
@@ -326,9 +327,9 @@ bool VTCore::ProcessCommands()
 		if( m_reg.model != VPB_OSW )
 			throw VpbException("set_codec_reg: Not an OpenSwitch card");
 
-		VT_REG_RW   bal  = { 0, mess[4] };
-		VT_DATA     data = { board:   m_reg.cardtypnum,
-				     channel: ch,
+		VT_REG_RW   bal  = { 0, uint8_t(mess[4]) };
+		VT_DATA     data = { board:   uint8_t(m_reg.cardtypnum),
+				     channel: uint8_t(ch),
 				     length:  sizeof(VT_REG_RW),
 				     data:    &bal
 				   };
@@ -389,7 +390,7 @@ void VTCore::CheckMsgQ()
 { //{{{
 	uint16_t    rmess[DSP_LDROP];
 	char        msgq[8] = { 0, 0, 0, 0, 0, 0, 0, 0 };
-	VT_DATA     mess  = { board:   m_reg.cardtypnum,
+	VT_DATA     mess  = { board:   uint8_t(m_reg.cardtypnum),
 			      channel: 0,
 			      length:  sizeof(msgq),
 			      data:    msgq
@@ -548,7 +549,7 @@ int VTCore::prepare_play_buf(int16_t *buf, int ch)
 	return (tonegen && tonegen->MixTone(buf,NBUF)) ? VPB_OK : retread;
 } //}}}
 
-static int vtcore_play_audio(int fd, int board, int port, int16_t *buf, int samples)
+static int vtcore_play_audio(int fd, uint8_t board, uint8_t port, int16_t *buf, unsigned samples)
 { //{{{
 	VT_DATA  mess = { board:    board,
 			  channel:  port,
@@ -558,7 +559,7 @@ static int vtcore_play_audio(int fd, int board, int port, int16_t *buf, int samp
 	return ioctl(fd, VT_IOC_CHANWRITEAUDIO, &mess) < 0 ? -1 : 0;
 } //}}}
 
-static int vtcore_play_fifo_how_empty(int fd, int board, int port)
+static int vtcore_play_fifo_how_empty(int fd, uint8_t board, uint8_t port)
 { //{{{
 	int tmp = 0;
 	VT_DATA  mess = { board:    board,
@@ -716,7 +717,7 @@ void VTCore::prepare_rec_buf(int16_t *buf, int ch)
 	}
 } //}}}
 
-static int vtcore_record_audio(int fd, int board, int port, int16_t *buf, int samples)
+static int vtcore_record_audio(int fd, uint8_t board, uint8_t port, int16_t *buf, unsigned samples)
 { //{{{
 	VT_DATA  mess = { board:    board,
 			  channel:  port,
@@ -779,7 +780,7 @@ void *VTCore::RecordThread(void *p)
 	return NULL;
 } //}}}
 
-static VPB_PORT vtcore_get_interface_type(int board, int port)
+static VPB_PORT vtcore_get_interface_type(uint8_t board, uint8_t port)
 { //{{{
 	int tmp = VPB_PORT_UNKNOWN;
 	VT_DATA  mess = { board:    board,
@@ -869,9 +870,9 @@ void VTCore::SetCountry( int port, const Country *country )
 			       "NEWZEALAND"
 			     };
 	vtcore_chan &chan  = ((vtcore_chan*)m_reg.chans)[port];
-	VT_DATA	     mess  = { board:    m_reg.cardtypnum,
-			       channel:  port,
-			       length:   strlen(country->name),
+	VT_DATA	     mess  = { board:    uint8_t(m_reg.cardtypnum),
+			       channel:  uint8_t(port),
+			       length:   unsigned(strlen(country->name)),
 			       data:     const_cast<char*>(country->name)
 			     };
 
@@ -979,9 +980,9 @@ void VTCore::SetVDAAImpedance( int port, int impedance )
 
 void VTCore::SetFlashTime( int port, uint16_t min, uint16_t max )
 { //{{{
-	VT_DATA	     mess  = { board:    m_reg.cardtypnum,
-			       channel:  port,
-			       length:   (max << 16) | min,
+	VT_DATA	     mess  = { board:    uint8_t(m_reg.cardtypnum),
+			       channel:  uint8_t(port),
+			       length:   unsigned(max) << 16 | min,
 			       data:     NULL
 			     };
 
@@ -1022,13 +1023,13 @@ float VTCore::GetHWRecordGain( unsigned int port )
 
 void VTCore::TapListen( unsigned int port, unsigned int srcboard, unsigned int srcport )
 { //{{{
-	VT_DATA  msg2 = { board:   srcboard,
-			  channel: srcport,
+	VT_DATA  msg2 = { board:   uint8_t(srcboard),
+			  channel: uint8_t(srcport),
 			  length:  0,
 			  data:    NULL
 			};
-	VT_DATA  mess = { board:   m_reg.cardtypnum,
-			  channel: port,
+	VT_DATA  mess = { board:   uint8_t(m_reg.cardtypnum),
+			  channel: uint8_t(port),
 			  length:  sizeof(VT_DATA),
 			  data:    &msg2
 			};
@@ -1039,8 +1040,8 @@ void VTCore::TapListen( unsigned int port, unsigned int srcboard, unsigned int s
 
 void VTCore::UNListen( unsigned int port )
 { //{{{
-	VT_DATA  mess = { board:   m_reg.cardtypnum,
-			  channel: port,
+	VT_DATA  mess = { board:   uint8_t(m_reg.cardtypnum),
+			  channel: uint8_t(port),
 			  length:  0,
 			  data:    NULL
 			};
@@ -1050,8 +1051,8 @@ void VTCore::UNListen( unsigned int port )
 void VTCore::config_bals( int port, int *bals )
 { //{{{
 	VT_REG_RW   bal;
-	VT_DATA     mess = { board:   m_reg.cardtypnum,
-			     channel: port,
+	VT_DATA     mess = { board:   uint8_t(m_reg.cardtypnum),
+			     channel: uint8_t(port),
 			     length:  sizeof(VT_REG_RW),
 			     data:    &bal
 			   };
@@ -1066,9 +1067,9 @@ void VTCore::config_bals( int port, int *bals )
 
 void VTCore::config_logging( int port, int logging )
 { //{{{
-	VT_DATA     mess = { board:   m_reg.cardtypnum,
-			     channel: port,
-			     length:  logging,
+	VT_DATA     mess = { board:   uint8_t(m_reg.cardtypnum),
+			     channel: uint8_t(port),
+			     length:  unsigned(logging),
 			     data:    NULL
 			   };
 	mprintf("VTCore: setting logging to %d\n", logging);
