@@ -59,7 +59,7 @@
 //#define PORT_CANT_ALLOCATE_MEMORY					107
 
 #define	VPBREG_REG_KEY_ACCESS_FAIL					200
-#define	VPBREG_NO_VPB_DEVICES_DETECTED					201
+//#define VPBREG_NO_VPB_DEVICES_DETECTED				201
 #define VPBREG_TOO_MANY_VPBS_ACCESSED					202
 #define VPBREG_REG_KEY_PROPERTY_FAIL					203
 //#define VPBREG_CANT_ALLOCATE_MEMORY					204
