@@ -78,7 +78,7 @@ int main(int argc, char *argv[])
 	}
 
 	size_t          NBUF = 16000;
-	double          gain = 0.0;
+	double          gain = 1.0;
 	int             arg;
 
 	if((arg = arg_exists(argc,argv,"--block")) != 0) {
@@ -119,7 +119,7 @@ int main(int argc, char *argv[])
 							buf, n / sizeof(int16_t),
 							&keydown);
 
-		printf("%#7x %6.2fs: Detected ", start, start / 16384.0);
+		printf("%7u %6.2fs: Detected ", start, start / 16000.0);
 		start += n;
 		count += digits_ret;
 
