@@ -37,7 +37,7 @@
 #include <csignal>
 
 
-#define MAX_CH 40
+#define MAX_CH 64
 
 static volatile sig_atomic_t sigint;
 
@@ -58,12 +58,12 @@ static int arg_exists(int argc, char *argv[], const char *arg)
 
 int main(int argc, char *argv[])
 {
-	int h[MAX_CH],
-	    state[MAX_CH],
-	    CH     = 8,
-	    FROM   = 0,
-	    bd     = 0,
-	    arg;
+	VPBPortHandle	h[MAX_CH];
+	HookState	state[MAX_CH];
+	int		CH     = 8;
+	int		FROM   = 0;
+	int		bd     = 0;
+	int		arg;
 
 	// setup SIGTERM/SIGINT handler to allow for an orderly exit
 	struct sigaction new_action;
@@ -90,11 +90,19 @@ int main(int argc, char *argv[])
 
 	for(int i = FROM; i < CH; ++i)
 	{
-		h[i] = vpb_open(bd,i);
-		vpb_disable_event(h[i], VPB_MRING);
-		state[i] = vpb_get_hookstate(h[i]);
-		if( state[i] == VPB_ONHOOK )
-			vpb_ring_station_async(h[i], VPB_RING_STATION_ON);
+		VPBPortHandle	handle = vpb_open(bd,i);
+
+		if( handle >= MAX_CH ) {
+			printf("Uh Oh, silly hardcoded limit of %d ports hit again\n",
+									MAX_CH);
+			goto uh_oh;
+		}
+		vpb_disable_event(handle, VPB_MRING);
+		state[handle] = vpb_get_hookstate(handle);
+		if( state[handle] == VPB_ONHOOK )
+			vpb_ring_station_async(handle, VPB_RING_STATION_ON);
+
+		h[i] = handle;
 	}
 
 	while( ! kbhit() && ! sigint )
@@ -126,6 +134,9 @@ int main(int argc, char *argv[])
 				state[e.handle] = VPB_ONHOOK;
 			}
 			break;
+
+		    case VPB_FASTOFFHOOK:
+			break;
 		}
 	}
 	printf("exiting ...\n");
@@ -135,6 +146,7 @@ int main(int argc, char *argv[])
 
 	vpb_sleep(2000);
 
+uh_oh:
 	vpb_close();
 
 	return 0;
