@@ -98,7 +98,7 @@ static void *worker_thread(void *p)
 					if( pthread_create(&contest_id,
 							   &detached_thread,
 							   contest_thread,
-							   (void*)h) )
+							   (void*)(intptr_t)h) )
 					{
 						fprintf(stderr,
 							"Failed to create contest thread\n");
@@ -283,7 +283,7 @@ int main(int argc, char *argv[])
 	pthread_attr_init(&detached_thread);
 	pthread_attr_setdetachstate(&detached_thread, PTHREAD_CREATE_DETACHED);
 
-	if( pthread_create(&worker_id, NULL, worker_thread, (void*)h) )
+	if( pthread_create(&worker_id, NULL, worker_thread, (void*)(intptr_t)h) )
 	{
 		fprintf(stderr, "Failed to create worker thread.  Aborting.\n");
 		return EXIT_FAILURE;
