@@ -4,8 +4,8 @@
 	Author: Ben Kramer, 24 October 2005
 	        Ron Lee, 8 Jun 2006
 
-	Copyright (C) 2005, 2006 Voicetronix www.voicetronix.com.au
-	Copyright (C) 2006, 2007 Ron Lee <ron@voicetronix.com.au>
+	Copyright (C) 2005 - 2013 Voicetronix www.voicetronix.com.au
+	Copyright (C) 2006 - 2013 Ron Lee <ron@voicetronix.com.au>
 
 	This library is free software; you can redistribute it and/or
 	modify it under the terms of the GNU General Public License
@@ -262,13 +262,13 @@ const char *get_pci_boardname(const struct pci_device_id *ent)
 	return (const char*)ent->driver_data;
 }
 
-static int __devinit openpci_probe_board(struct pci_dev *pdev, const struct pci_device_id *ent);
-static void __devexit openpci_remove_board(struct pci_dev *pdev);
+static int openpci_probe_board(struct pci_dev *pdev, const struct pci_device_id *ent);
+static void openpci_remove_board(struct pci_dev *pdev);
 
 static struct pci_driver vtopenpci_driver = {
 	.name     = NAME,
 	.probe    = openpci_probe_board,
-	.remove   = __devexit_p(openpci_remove_board),
+	.remove   = openpci_remove_board,
 	.suspend  = NULL,
 	.resume   = NULL,
 	.id_table = openpci_idtable
@@ -277,7 +277,7 @@ static struct pci_driver vtopenpci_driver = {
 //XXX Use me!
 //static struct workqueue_struct *openpci_workqueue; // = NULL
 
-static int  shareirq = 1;
+static bool shareirq = 1;
 static char *country = DEFAULT_COUNTRY;
 static char *program; // = NULL
 static int  debug;    // = 0;
@@ -642,6 +642,12 @@ static int configure_vdaa_country(struct openpci *card, int port, const char *na
 		return -EIO;
 	}
 	card->chans[port].country = country_regs[i].country;
+
+	if( ! write_reg_fxo(card, port, VDAR_RVC1, 0x16) ){
+		cardcrit(card->cardnum,
+			 "write VDAR_RVC1=0x16 failed on port %d", port);
+		return -EIO;
+	}
 	return 0;
 } //}}}
 
@@ -2201,34 +2207,20 @@ static void get_module_info( struct openpci *card )
 	cardinfo(card->cardnum, "failed to get module info");
 } //}}}
 
-static int create_module_proc_const_int(struct openpci *card, int module,
+static void create_module_proc_const_int(struct openpci *card, int module,
 					const char *node, long val)
 { //{{{
-	struct proc_dir_entry *p;
-
-	p = create_proc_read_entry(node, 0444, card->moduleinfo[module].procfs_root,
-					 vt_proc_read_int, (void*)val);
-	if (p) {
-		set_proc_owner(p, THIS_MODULE);
-		return RET_OK;
-	}
-	crit("failed to create procfs module%d/%s", module, node);
-	return RET_FAIL;
+	if (!proc_create_data(node, S_IRUGO, card->moduleinfo[module].procfs_root,
+				 &vt_int_proc_fops, (void*)val))
+		crit("failed to create procfs module%d/%s", module, node);
 } //}}}
 
-static int create_module_proc_const_string(struct openpci *card, int module,
+static void create_module_proc_const_string(struct openpci *card, int module,
 					   const char *node, const char *str)
 { //{{{
-	struct proc_dir_entry *p;
-
-	p = create_proc_read_entry(node, 0444, card->moduleinfo[module].procfs_root,
-					 vt_proc_read_string, (void*)str);
-	if( p ){
-		set_proc_owner(p, THIS_MODULE);
-		return RET_OK;
-	}
-	crit("failed to create procfs module%d/%s", module, node);
-	return RET_FAIL;
+	if (!proc_create_data(node, S_IRUGO, card->moduleinfo[module].procfs_root,
+				 &vt_string_proc_fops, (void*)str))
+		crit("failed to create procfs module%d/%s", module, node);
 } //}}}
 
 // The card must be registered with vtcore before this function is called.
@@ -2252,7 +2244,6 @@ static void export_module_info( struct openpci *card )
 			cardcrit(card->cardnum, "failed to create procfs module%d", i);
 			continue;
 		}
-		set_proc_owner(*modroot, THIS_MODULE);
 
 		create_module_proc_const_string(card, i, "type", mod->type );
 		create_module_proc_const_int(card, i, "ports", mod->ports );
@@ -2271,6 +2262,11 @@ static void unexport_module_info( struct openpci *card )
 		char  dirname[16] = { 0 };
 		struct proc_dir_entry *modroot = card->moduleinfo[i].procfs_root;
 
+		// We could just replace all of this with a call to:
+		// proc_remove(modroot);
+		// but it and remove_proc_subtree didn't appear until v3.9-rc5
+		// so stick with what works with older kernels for a bit longer.
+
 		snprintf(dirname, sizeof(dirname)-1, "module%d", i);
 
 		remove_proc_entry("type", modroot);
@@ -2321,8 +2317,7 @@ static void vtopenpci_board_unregister( struct openpci *card )
 	vt_board_unregister(board);
 } //}}}
 
-static int __devinit openpci_probe_board(struct pci_dev *pdev,
-					 const struct pci_device_id *ent)
+static int openpci_probe_board(struct pci_dev *pdev, const struct pci_device_id *ent)
 { //{{{
 	struct openpci *card;
 	int cardnum = 0;
@@ -2556,7 +2551,7 @@ static void force_station_onhook(struct openpci *card, int port)
 	}
 } //}}}
 
-static void __devexit openpci_remove_board(struct pci_dev *pdev)
+static void openpci_remove_board(struct pci_dev *pdev)
 { //{{{
 	struct openpci *card = pci_get_drvdata(pdev);
 	unsigned long flags;
