@@ -11,8 +11,8 @@
 	    Peter Wintulich, 2003.
 
 
-         Copyright (C) Voicetronix 2005, 2006 support@voicetronix.com.au
-	 Copyright (C) 2006, 2007 Ron Lee <ron@voicetronix.com.au>
+	 Copyright (C) 2005 - 2013 Voicetronix www.voicetronix.com.au
+	 Copyright (C) 2006 - 2013, Ron Lee <ron@voicetronix.com.au>
 
          This library is free software; you can redistribute it and/or
          modify it under the terms of the GNU General Public License
@@ -273,21 +273,20 @@ static struct pci_device_id openswitch_idtable[] = {
 };
 MODULE_DEVICE_TABLE(pci, openswitch_idtable);
 
-static int  __devinit openswitch_probe_board(struct pci_dev *pdev,
-					     const struct pci_device_id *ent);
-static void __devexit openswitch_remove_board(struct pci_dev *pdev);
+static int openswitch_probe_board(struct pci_dev *pdev, const struct pci_device_id *ent);
+static void openswitch_remove_board(struct pci_dev *pdev);
 
 static struct pci_driver vtopenswitch_driver = {
 	.name     = NAME,
 	.probe    = openswitch_probe_board,
-	.remove   = __devexit_p(openswitch_remove_board),
+	.remove   = openswitch_remove_board,
 	.suspend  = NULL,
 	.resume   = NULL,
 	.id_table = openswitch_idtable
 };
 
 
-static int shareirq = 1;
+static bool shareirq = 1;
 static int debug;
 
 module_param(shareirq, bool, 0444);
@@ -1582,8 +1581,7 @@ static int vtopenswitch_board_register(struct openswitch *card)
 	return RET_OK;
 } //}}}
 
-static int __devinit openswitch_probe_board(struct pci_dev *pdev,
-					    const struct pci_device_id *ent)
+static int openswitch_probe_board(struct pci_dev *pdev, const struct pci_device_id *ent)
 { //{{{
 	struct openswitch *card;
 	int cardnum = 0;
@@ -1858,7 +1856,7 @@ static void force_station_onhook(struct openswitch *card, int port)
 	set_audio_off( card, port );
 } //}}}
 
-static void __devexit openswitch_remove_board(struct pci_dev *pdev)
+static void openswitch_remove_board(struct pci_dev *pdev)
 { //{{{
 	struct openswitch *card = pci_get_drvdata(pdev);
 	int    i = 0;
