@@ -140,10 +140,7 @@ int main(int argc, char * argv[])
 		cinfo[i].run=RUN_GO;
 	}
 	vpb_sleep(1000);
-//	for(i=0; i<num_ch/2;i++){
-//	for(i=0; i<5;i++){
-	for(i=0; i<30;i++){
-//	for(i=0; i<15;i++){
+	for(i=0; i<num_ch/2;i++){
 		cinfo[i].run=RUN_GO;
 	}
 
@@ -156,7 +153,7 @@ int main(int argc, char * argv[])
 		}
 		ret = vpb_get_event_sync(&e,500);
 		if (ret == VPB_OK) {
-//			myprintf("main: Got an event [%d] on [%d]\n",e.type,e.handle);
+			myprintf("main: Got an event [%d] on [%d]\n",e.type,e.handle);
 		}
 	}
 
@@ -232,9 +229,7 @@ void *call_gen_thread(void *pv) {
 						case VPB_ISDN_ANS:
 							myprintf("chan[%d]: Call was answered!\n",cinfo->handle);
 							sleep(1);
-							//myprintf("chan[%d]: Dialing DTMF's (%s)\n",cinfo->handle,cid);
 							vpb_dial_sync(cinfo->handle,cid);
-							//myprintf("chan[%d]: Dialed DTMF's (%s)\n",cinfo->handle,cid);
 							newstate = CALL_ANS;
 							dtmf_idx=0;
 							break;
@@ -274,7 +269,6 @@ void *call_gen_thread(void *pv) {
 							collected_dtmf[dtmf_idx]=e.data;
 							dtmf_idx++;
 							collected_dtmf[dtmf_idx]=0;
-							//myprintf("chan[%d]: Got DTMF [%d] [%s]\n",cinfo->handle,e.data,collected_dtmf);
 							if (strcmp(collected_dtmf,"88")==0){
 								myprintf("chan[%d]: They got what we sent!\n",cinfo->handle);
 								call_progress=1;
@@ -282,7 +276,6 @@ void *call_gen_thread(void *pv) {
 								dtmf_state=1;
 							}
 							else if (strcmp(collected_dtmf,number)==0){
-								//myprintf("chan[%d]: Hey they are who they should be! Time to write a record and start again!\n",cinfo->handle);
 								call_passed(cinfo->handle);
 								vpb_dial_sync(cinfo->handle,"77");
 								vpb_timer_stop(call_timer);
@@ -377,11 +370,6 @@ void *call_rec_thread(void *pv) {
 	VPB_CALL_INFO *call_info;
 	char collected_dtmf[30];
 	int  dtmf_idx =0;
-/*
-	int  call_count=0;
-	int	call_count_pass=0;
-	int	call_count_fail=0;
-*/
 	int  call_progress=0;
 	void	*call_timer;
 	int dtmf_state=0;
@@ -466,7 +454,6 @@ void *call_rec_thread(void *pv) {
 						collected_dtmf[dtmf_idx]=e.data;
 						dtmf_idx++;
 						collected_dtmf[dtmf_idx]=0;
-//						myprintf("chan[%d]: Got a DTMF [%d] [%s]!\n",e.handle,e.data,collected_dtmf);
 						if (strcmp(call_info->callingnum,collected_dtmf)==0){
 							myprintf("chan[%d]: We got the DTMF's we where looking for!\n",e.handle);
 							dtmf_idx=0;
@@ -477,7 +464,6 @@ void *call_rec_thread(void *pv) {
 							vpb_dial_sync(cinfo->handle,call_info->callednum);
 						}
 						else if (strcmp(collected_dtmf,"77")==0){
-							//myprintf("chan[%d]: Cool, we got it all, time to write a pass\n",e.handle);
 							call_progress=2;
 							call_passed(cinfo->handle);
 							dtmf_idx=0;
@@ -494,7 +480,7 @@ void *call_rec_thread(void *pv) {
 						/* Do nothing! */
 					}
 					else if (e.type == VPB_TONEDETECT){
-//						myprintf("chan[%d]: Got a tone type [%d]\n",cinfo->handle,e.data);
+						myprintf("chan[%d]: Got a tone type [%d]\n",cinfo->handle,e.data);
 					}
 					else if (e.type == VPB_DTMF_DOWN){
 						/* Do nothing! */
